@@ -7,5 +7,7 @@ if(getRversion() >= "2.15.1")
     c("capitals", "ccode_democracy", "cow_alliance", "cow_contdir",
       "cow_ddy", "cow_gw_years", "cow_majors", "cow_states",
       "gml_dirdisp", "gw_ddy", "gw_states", "maoz_powers", "cow_nmc",
-      "cow_igo_ndy", "cow_igo_sy", "cow_trade_sy")
+      "cow_igo_ndy", "cow_igo_sy", "cow_trade_sy", "gw_mindist", "cow_mindist",
+      "archigos", "atop_alliance", "gw_sdp_gdp", "cow_sdp_gdp", "ucdp_onsets",
+      "ucdp_acd")
   )
